@@ -29,6 +29,8 @@ sub new {
         Bool :find_master
     )' );
 
+    $args{ 'auth_db_name' } //= 'admin';
+
     unless( exists $args{ 'find_master' } ) {
 
         $args{ 'find_master' } = true;
@@ -83,11 +85,7 @@ sub _connect {
 
     } else {
 
-        my ( $login, $password ) = @{ $self
-            -> { '_auth_info' }
-            -> { 'db_auth' }
-            -> { $self -> { 'use_auth_for' } }
-        }{ 'login', 'password' };
+        my ( $login, $password ) = @{ $self -> credentials() }{ 'login', 'password' };
 
         $self -> { '_connection' } = MongoDB::MongoClient -> new(
             host => "mongodb://${mongo_servers_list}",
@@ -98,7 +96,7 @@ sub _connect {
             auto_connect => 1,
             w => 1,
             dt_type => undef,
-            db_name => ( $self -> { 'auth_db_name' } // 'admin' ),
+            db_name => $self -> { 'auth_db_name' },
             ( defined $login ? ( username  => $login ) : () ),
             ( defined $password ? ( password => $password ) : () ),
         );
@@ -112,6 +110,21 @@ sub _connect {
     return $self -> { '_connection' };
 }
 
+sub credentials {
+
+    my ( $self ) = @_;
+    my ( $login, $password ) = @{ $self
+        -> { '_auth_info' }
+        -> { 'db_auth' }
+        -> { $self -> { 'use_auth_for' } }
+    }{ 'login', 'password' };
+
+    return {
+        login => $login,
+        password => $password,
+    };
+}
+
 sub config_file {
 
     my ( $self ) = @_;
